==> fillets-ng-data-0.7.1.tar.gz: fillets-ng-data-0.7.1/script/cellar/dialogs_de.lua <==

dialogId("pra-m-pravidla", "font_small", "You know the rules already. Now you can practice them. We will give you some hints occasionally.")
dialogStr("Du kennst die Regeln bereits. Jetzt kannst du sie üben. Wir werden dir gelegentlich Tipps geben.")


dialogId("pra-v-klesnout", "font_big", "I must not swim down now. And I cannot go up, either.")
dialogStr("Ich darf nicht nach unten schwimmen. Ich kann auch nicht nach oben.")


dialogId("pra-v-nahore", "font_big", "Hey, arrange it up there somehow. But be careful!")
dialogStr("He, Räum da oben mal ein bisschen auf. Aber sei vorsichtig!")


dialogId("pra-m-nepohnu", "font_small", "I can`t move this. This is steel.")
dialogStr("Das kann ich nicht bewegen. Das ist Stahl.")


dialogId("pra-m-zpatky", "font_small", "Come back, you can`t go further!")
dialogStr("Komm zurück, du kannst nicht weiter!")


dialogId("pra-v-zapeklita", "font_big", "Hmm... This is tricky. If we push aside the honey, we will be smashed by that can of apricot jam.")
dialogStr("Hmm... das ist kniffelig. Wenn wir den Honig zur Seite schieben, werden wir von der Aprikosen-Marmelade erdrückt.")


dialogId("pra-m-vyrazit", "font_small", "Couldn`t we push it aside with that axe?")
dialogStr("Können wir ihn nicht mit der Axt schieben?")


dialogId("pra-v-dobrynapad", "font_big", "That`s a good idea.")
dialogStr("Das ist eine gute Idee.")


dialogId("pra-m-chytit", "font_small", "Now I cannot take the axe. The can is in the way.")
dialogStr("Jetzt komme ich nicht mehr an die Axt. Das Glas ist im Weg.")


dialogId("pra-v-vzit", "font_big", "You mustn`t push the axe!")
dialogStr("Du darfst die Axt nicht schieben!")


dialogId("pra-m-prisun", "font_small", "If you can push that can to me, I`ll shove the axe on it and everything will be okay.")
dialogStr("Wenn du das Glas zu mir schiebst, schubse ich die Axt drauf und alles wird gut.")


dialogId("pra-v-problem", "font_big", "If you solve some specific part you can save the position.")
dialogStr("Wenn du einen Teil erledigt hast, kannst du die Situation abspeichern.")


dialogId("pra-m-reseni", "font_small", "But only if you are sure of your solution.")
dialogStr("Aber nur, wenn du dir deiner Lösung sicher bist.")


dialogId("pra-v-ukladani", "font_big", "Remember what we have said about saving positions.")
dialogStr("Erinnere dich daran, was wir über das Abspeichern von Situationen gesagt haben..")


dialogId("pra-m-uvazovat", "font_small", "I shouldn`t be thinking about this.")
dialogStr("Darüber sollte ich erst gar nicht nachdenken.")


dialogId("pra-v-spatne", "font_big", "This looks real bad. You are going to have to restart the level.")
dialogStr("Das sieht ziemlich schlecht aus. Du musst die Ebene neustarten.")


dialogId("pra-m-pustis", "font_small", "If you drop that and I stay here, I will never get out.")
dialogStr("Wenn du das fallenlässt und ich hierbleibe, komme ich nie raus.")


dialogId("pra-v-zavazis", "font_big", "You are standing in my way there. Try to hide somewhere else.")
dialogStr("Du bist mir im Weg. Versuche, dich woanders zu verstecken.")


dialogId("pra-m-strach", "font_small", "Here? I`m little bit afraid. Will I get out?")
dialogStr("Hier? Ich hab ein bisschen Angst. Komme ich hier wieder raus?")


dialogId("pra-v-prekvapit", "font_big", "Just wait and see.")
dialogStr("Abwarten und Tee trinken.")


dialogId("pra-m-kniha", "font_small", "We will give you a hint here, player. You have to put that book over there, to the left.")
dialogStr("Wir werden dir hier einen einen Tipp geben, Spieler. Du musst das Buch nach da drüben links bringen.")


dialogId("pra-v-valec", "font_big", "So that it will catch that steel cylinder when I push it.")
dialogStr("So dass es den Stahlzylinder auffängt, wenn ich ihn schubse.")


dialogId("pra-m-jakudelat", "font_small", "But we will not tell you how to do it.")
dialogStr("Wir werden dir aber nicht sagen, wie.")


dialogId("pra-v-nezapomen", "font_big", "Just remember that although we cannot push objects along each other`s back, we can push them down or onto some solid structure.")
dialogStr("Erinnere dich: Wir können uns zwar keine Gegenstände über den Rücken schieben, aber wir können Sie runter oder auf eine feste Oberfläche schubsen.")


dialogId("pra-v-objet", "font_big", "What if I go the upper way?")
dialogStr("Und was, wenn ich den oberen Weg nehme?")


dialogId("pra-m-neradit", "font_small", "Shhhh. That`s too many hints.")
dialogStr("Pssst. Das sind zu viele Tipps.")


dialogId("pra-m-stava", "font_small", "Things like that happen sometimes.")
dialogStr("Sowas passiert manchmal.")


dialogId("pra-v-dopredu", "font_big", "Sometimes you have to think faaar ahead.")
dialogStr("Manchmal musst du seeehr weit vorausdenken.")


dialogId("pra-m-restart", "font_small", "And often you have to restart the level then.")
dialogStr("Und häufig musst du dann die Ebene neustarten.")


dialogId("pra-v-schvalne", "font_big", "We admit that we did this on purpose.")
dialogStr("Wir geben zu, dass wir das mit Absicht getan haben.")


dialogId("pra-m-znovu", "font_small", "So that you could try it again - this time without any hints.")
dialogStr("So dass du nochmal versuchen kannst - ohne Tipps.")

==> fillets-ng-data_1.0.1.orig.tar.gz: fillets-ng-data-1.0.1/script/cellar/dialogs_de.lua <==

dialogId("pra-m-pravidla", "font_small", "You know the rules already. Now you can practice them. We will give you some hints occasionally.")
dialogStr("Du kennst die Regeln bereits. Jetzt kannst du sie üben. Wir werden dir gelegentlich Tipps geben.")


dialogId("pra-v-klesnout", "font_big", "I must not swim down now. And I cannot go up, either.")
dialogStr("Ich darf nicht nach unten schwimmen. Ich kann auch nicht nach oben.")


dialogId("pra-v-nahore", "font_big", "Hey, arrange it up there somehow. But be careful!")
dialogStr("He, Räum da oben mal ein bisschen auf. Aber sei vorsichtig!")


dialogId("pra-m-nepohnu", "font_small", "I can’t move this. This is steel.")
dialogStr("Das kann ich nicht bewegen. Das ist Stahl.")


dialogId("pra-m-zpatky", "font_small", "Come back, you can’t go further!")
dialogStr("Komm zurück, du kannst nicht weiter!")


dialogId("pra-v-zapeklita", "font_big", "Hmm... This is tricky. If we push aside the honey, we will be smashed by that can of apricot jam.")
dialogStr("Hmm... das ist kniffelig. Wenn wir den Honig zur Seite schieben, werden wir von der Aprikosen-Marmelade erdrückt.")


dialogId("pra-m-vyrazit", "font_small", "Couldn’t we push it aside with that axe?")
dialogStr("Können wir ihn nicht mit der Axt schieben?")


dialogId("pra-v-dobrynapad", "font_big", "That’s a good idea.")
dialogStr("Das ist eine gute Idee.")


dialogId("pra-m-chytit", "font_small", "Now I cannot take the axe. The can is in the way.")
dialogStr("Jetzt komme ich nicht mehr an die Axt. Das Glas ist im Weg.")


dialogId("pra-v-vzit", "font_big", "You mustn’t push the axe!")
dialogStr("Du darfst die Axt nicht schieben!")


dialogId("pra-m-prisun", "font_small", "If you can push that can to me, I’ll shove the axe on it and everything will be okay.")
dialogStr("Wenn du das Glas zu mir schiebst, schubse ich die Axt drauf und alles wird gut.")


dialogId("pra-v-problem", "font_big", "If you solve some specific part you can save the position.")
dialogStr("Wenn du einen Teil erledigt hast, kannst du die Situation abspeichern.")


dialogId("pra-m-reseni", "font_small", "But only if you are sure of your solution.")
dialogStr("Aber nur, wenn du dir deiner Lösung sicher bist.")


dialogId("pra-v-ukladani", "font_big", "Remember what we have said about saving positions.")
dialogStr("Erinnere dich daran, was wir über das Abspeichern von Situationen gesagt haben..")


dialogId("pra-m-uvazovat", "font_small", "I shouldn’t be thinking about this.")
dialogStr("Darüber sollte ich erst gar nicht nachdenken.")


dialogId("pra-v-spatne", "font_big", "This looks real bad. You are going to have to restart the level.")
dialogStr("Das sieht ziemlich schlecht aus. Du musst die Ebene neustarten.")


dialogId("pra-m-pustis", "font_small", "If you drop that and I stay here, I will never get out.")
dialogStr("Wenn du das fallenlässt und ich hierbleibe, komme ich nie raus.")


dialogId("pra-v-zavazis", "font_big", "You are standing in my way there. Try to hide somewhere else.")
dialogStr("Du bist mir im Weg. Versuche, dich woanders zu verstecken.")


dialogId("pra-m-strach", "font_small", "Here? I’m little bit afraid. Will I get out?")
dialogStr("Hier? Ich hab ein bisschen Angst. Komme ich hier wieder raus?")


dialogId("pra-v-prekvapit", "font_big", "Just wait and see.")
dialogStr("Abwarten und Tee trinken.")


dialogId("pra-m-kniha", "font_small", "We will give you a hint here, player. You have to put that book over there, to the left.")
dialogStr("Wir werden dir hier einen einen Tipp geben, Spieler. Du musst das Buch nach da drüben links bringen.")


dialogId("pra-v-valec", "font_big", "So that it will catch that steel cylinder when I push it.")
dialogStr("So dass es den Stahlzylinder auffängt, wenn ich ihn schubse.")


dialogId("pra-m-jakudelat", "font_small", "But we will not tell you how to do it.")
dialogStr("Wir werden dir aber nicht sagen, wie.")


dialogId("pra-v-nezapomen", "font_big", "Just remember that although we cannot push objects along each other’s back, we can push them down or onto some solid structure.")
dialogStr("Erinnere dich: Wir können uns zwar keine Gegenstände über den Rücken schieben, aber wir können Sie runter oder auf eine feste Oberfläche schubsen.")


dialogId("pra-v-objet", "font_big", "What if I go the upper way?")
dialogStr("Und was, wenn ich den oberen Weg nehme?")


dialogId("pra-m-neradit", "font_small", "Shhhh. That’s too many hints.")
dialogStr("Pssst. Das sind zu viele Tipps.")


dialogId("pra-m-stava", "font_small", "Things like that happen sometimes.")
dialogStr("Sowas passiert manchmal.")


dialogId("pra-v-dopredu", "font_big", "Sometimes you have to think faaar ahead.")
dialogStr("Manchmal musst du seeehr weit vorausdenken.")


dialogId("pra-m-restart", "font_small", "And often you have to restart the level then.")
dialogStr("Und häufig musst du dann die Ebene neustarten.")


dialogId("pra-v-schvalne", "font_big", "We admit that we did this on purpose.")
dialogStr("Wir geben zu, dass wir das mit Absicht getan haben.")


dialogId("pra-m-znovu", "font_small", "So that you could try it again - this time without any hints.")
dialogStr("So dass du nochmal versuchen kannst - ohne Tipps.")
